/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://www.osor.eu/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef NPP_DPPREADER_H
#define NPP_DPPREADER_H

#include <string>
#include <stdint.h>
#include <fstream>
#include <sstream>

namespace npp {

class DPPReader {

public:
	/**
	 * Constructor.
	 */
	DPPReader(int32_t size);

	/**
	 * Destructor.
	 */
	virtual ~DPPReader();

	/**
	 * Opens the file. Returns false if problem opening the file.
	 */
	bool openFile(std::string const & fileName);

	/**
	 * Returns the number of ADC.
	 */
	int32_t numberOfADCs() const;

	/**
	 * Returns the number of channels.
	 */
	int32_t numberOfChannels() const;

	/**
	 * Returns the list mode.
	 */
	int32_t listMode() const;

	/**
	 * Returns the list mode size.
	 */
	int32_t numberOfEvents() const;

	/**
	 * Returns the number of elements read.
	 */
	int32_t readBlock();

	/**
	 * Returns the memory block.
	 */
	int32_t * memoryBlock() const;

private:
	void init(int32_t size);
	int32_t getBlockSizeInBytes();

	int32_t _size;
	int32_t _sizeInBytes;

	int32_t * _memoryBlock;
	std::ifstream _dataFile;

	int32_t _nbAdc;
	int32_t _nbChannels;
	int32_t _listMode;
	int32_t _listModeSize;

	typedef std::ifstream::pos_type FileSize;
	FileSize _fileSize;
};

}

#endif
