/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include <cmath>
#include <bitset>

#include "drivers/stereo_elec/StereoElecDef.h"

#include "DAQConfigController.h"
#include "controllers/common/family/Families.h"

using namespace std;

namespace stereo_daq {

const string DAQConfigController::TYPE = "daqconfig_controller";

/*
 * Constructor
 */
DAQConfigController::DAQConfigController(const string& name) :
		ExperimentController(name),Config(this),Reset(this) {

	setFamily(family::ACQUISITION);

	// Init property

	m_ELECDriver.init(this, "driver");

	m_StartActivated = false;


	registerFunction(TYPE);



}

DAQConfigController::DAQConfigController(const DAQConfigController& controller) :
		ExperimentController(controller), Config(this),Reset(this) {

	m_ELECDriver.copy(controller.m_ELECDriver);
	m_StartActivated = false;
}

/*
 * Destructor
 */
DAQConfigController::~DAQConfigController() {
	// Empty
}

void DAQConfigController::postConfiguration() {
	registerProgression(m_ELECDriver, &DAQConfigController::updateProgression, this);



}

/*
 * updateProgression
 */
void DAQConfigController::updateProgression() {
	// Calculate its own progression to manage retry case
	int32 progression = m_ELECDriver->commandProgression();
	if (progression >= 100) {
		progression = 99;
	}
	commandProgression = progression;
}




/*
 * select channels
 */
void DAQConfigController::config() {
	m_ELECDriver->execute("config");

}

void DAQConfigController::reset() {
	m_ELECDriver->execute("reset");
}

}

