/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef DAQCONFIGCONTROLLER_H
#define DAQCONFIGCONTROLLER_H

#include <Controller.h>
#include "drivers/stereo_elec/StereoElecDriver.h"


namespace stereo_daq {

/*!
 * \brief Commands select to be used as a thread.
 */
class Config: private controller::Command {

public:
	Config(ExperimentController * c) :
			controller::Command(c, "config", &Config::config, this) {
	}

	virtual void config() = 0;
	void configCommand(bool logging = false) {
		command(logging, true);
	}
};

/*!
 * \brief Commands set to be used as a thread.
 */
class Reset: private controller::Command {

public:
	Reset(ExperimentController * c) :
			controller::Command(c, "reset", &Reset::reset, this) {
	}

	virtual void reset() = 0;
	void resetCommand(bool logging = false) {
		command(logging, true);
	}
};

/*!
 * \class DAQConfigController
 */

class DAQConfigController : public ExperimentController,public Config, public Reset {

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 *
	 * It is the default constructor called by the creator class ExperimentControllerCreator.
	 *
	 * \param[in] name the name of the controller
	 */
	DAQConfigController(const std::string& name);

	/*!
	 * \brief Copy constructor
	 *
	 * \param[in] controller the controller to copy
	 */
	DAQConfigController(const DAQConfigController& controller);

	/*!
	 * \brief Destructor
	 */
	virtual ~DAQConfigController();

	/*!
	 * \brief Method called before changing the property value
	 *
	 * This method is called after setting configuration during the creation of controller.
	 */
	virtual void postConfiguration();

	/*!
	 * Properties
	 */


protected:

	DriverPtr<stereo_elec::StereoElecDriver> m_ELECDriver; //! The driver linked to the controller

	/*!
	 * \brief select command
	 */
	virtual void config();

	/*!
	 * \brief select command
	 */
	virtual void reset();



private:
	/*
	 * local values
	 */
		bool m_StartActivated; //! Started activated flag

		void updateProgression();
};
}
#endif // DAQCONFIGCONTROLLER_H
