/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef REALUSBPVCAMDRIVER_H
#define REALUSBPVCAMDRIVER_H

#include "UsbPVCamState.h"
#include "UsbPVCamDef.h"

#include "Utilities/Counter.h"

namespace usbpvcam {

/*!
 * \class RealUsbPVCamDriver
 * \brief Real implementation class for the UsbPVCam device driver
 *
 * This class is a real implementation of UsbPVCam device driver.
 */
class RealUsbPVCamDriver: public UsbPVCamState {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	RealUsbPVCamDriver(UsbPVCamDriver* owner);

	/*!
	 * \brief Destructor
	 */
	virtual ~RealUsbPVCamDriver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Start command implementation
	 */
	virtual void start();

	/*!
	 * \brief Resume command implementation
	 */
	virtual void resume();

	/*!
	 * \brief Pause command implementation
	 */
	virtual void pause();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

private:

	void print_pv_error();
	int16 m_Handle;
	Counter m_TimeCounter;
};

}
#endif //REALUSBPVCAMDRIVER_H
